# Taipy GUI

## License
Copyright 2021-2024 Avaiga Private Limited

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
the License. You may obtain a copy of the License at
[http://www.apache.org/licenses/LICENSE-2.0](https://www.apache.org/licenses/LICENSE-2.0.txt)

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.

## Usage
- [License](#license)
- [Usage](#usage)
- [Taipy GUI](#what-is-taipy-gui)
- [Installation](#installation)
- [Contributing](#contributing)
- [Code of conduct](#code-of-conduct)
- [Directory Structure](#directory-structure)

## What is Taipy GUI

Taipy is a Python library for creating Business Applications. More information on our
[website](https://www.taipy.io). Taipy is split into multiple repositories including `taipy-gui` to let users
install the minimum they need.

Taipy GUI provides Python classes that make it easy to create powerful web apps in minutes.

A more in depth documentation of Taipy can be found [here](https://docs.taipy.io/).

## Installation

Want to install and try *Taipy GUI*? Check out our [`INSTALLATION.md`](INSTALLATION.md) file.

## Contributing

Want to help build *Taipy GUI*? Check out our [`CONTRIBUTING.md`](CONTRIBUTING.md) file.

## Code of conduct

Want to be part of the *Taipy GUI* community? Check out our [`CODE_OF_CONDUCT.md`](CODE_OF_CONDUCT.md) file.

## Directory Structure

- `frontend/taipy-gui`: Graphical user interface related files;
- `taipy/gui`: Python source files;
- `tests/gui`: Unit tests;
- `tools`: Files used to document `taipy-gui`;
- `CODE_OF_CONDUCT.md`: Code of conduct for members and contributors of `taipy-gui`;
- `CONTRIBUTING.md`: Instructions to contribute to `taipy-gui`;
- `INSTALLATION.md`: Instructions to build and install `taipy-gui`;
- `LICENSE`: The Apache 2.0 License;
- `README.md`: Current file;
- `setup.py`: The setup script managing building, distributing, and installing `taipy-gui`;
